@@ -14,10 +14,12 @@ function(rho,
     ## calculating x & y coordinates for data points
 
     ## for drawing data
-    x.dat <- as.vector(sweep(transf(rho)-transf(grid$ray$lim[1]),MAR=1,
+    x.dat <- as.vector(sweep(transf(rho)-transf(grid$ray$lim[1]),
+                             MARGIN = 1,
                              sin(2*pi*(cyclVar+general$shift)/circle),
                              "*"))
-    y.dat <- as.vector(sweep(transf(rho)-transf(grid$ray$lim[1]),MAR=1,
+    y.dat <- as.vector(sweep(transf(rho)-transf(grid$ray$lim[1]),
+                             MARGIN = 1,
                              cos(2*pi*(cyclVar+general$shift)/circle),
                              "*"))
     id.dat <- rep(1:ncol(rho), rep(nrow(rho),ncol(rho)))
